<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor repay-blog-post Widget.
 *
 * Elementor widget that uses the repay-blog-post control.
 *
 * @since 1.0.0
 */
class Elementor_Repay_Blog_Post_Widget extends \Elementor\Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve repay-blog-post widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'repay-blog-post';
	}
	/**
	 * Get widget title.
	 *
	 * Retrieve repay-blog-post widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Repay Blog Posts', 'elementor-repay-blog-post-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve repay-blog-post widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */

	/**
	 * Register repay-blog-post widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
        
        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-repay-blog-post-control' ),
				'type' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_post_blogs',
			[
				'label' => __( 'Number of Posts', 'elementor-repay-blog-post-control' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 3, // Set a default value
				'min' => 1,
				'max' => 100,
				'step' => 1,
			]
		);
		$this->add_control(
			'button_text', [
				'label' => __( 'Button Text', 'elementor-repay-blog-post-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Read More' , 'elementor-repay-blog-post-control' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'post_blog_category',
			[
				'label' => esc_html__( 'Select Post Category', 'elementor-repay-blog-post-control' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_post_blog_categories(),
				'default' => 'post',
			]
		);
        $this->end_controls_section();
		$this->start_controls_section(
			'post_order_section',
			[
				'label' => esc_html__('Post Order', 'elementor-repay-blog-post-control'),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label'   => esc_html__('Post Order', 'elementor-repay-blog-post-control'),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'asc'  => [
						'title' => esc_html__('Ascending', 'elementor-repay-blog-post-control'),
						'icon'  => 'fa fa-sort-amount-asc',
					],
					'desc' => [
						'title' => esc_html__('Descending', 'elementor-repay-blog-post-control'),
						'icon'  => 'fa fa-sort-amount-desc',
					],
				],
				'default' => 'desc',
			]
		);
		
		$this->add_control(
			'post_order_by',
			[
				'label'   => esc_html__('Sort Order', 'elementor-repay-blog-post-control'),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'date'  => [
						'title' => esc_html__('Latest Posts', 'elementor-repay-blog-post-control'),
						'icon'  => 'fa fa-calendar',
					],
					'title' => [
						'title' => esc_html__('Alphabetical Order', 'elementor-repay-blog-post-control'),
						'icon'  => 'fa fa-sort-alpha-asc',
					],
				],
				'default' => 'date',
			]
		);
		
		$this->end_controls_section();
		$this->start_controls_section(
			'image_section',
			[
				'label' => esc_html__( 'Image Controls', 'elementor-repay-blog-post-control' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_responsive_control(
			'image_size',
			[
				'label' => esc_html__( 'Image Size', 'elementor-repay-blog-post-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'full', // Set your default image size
				'options' => [
					'thumbnail' => 'Thumbnail',
					'medium' => 'Medium',
					'large' => 'Large',
					'full' => 'Full',
				],
			]
		);
		
		$this->end_controls_section();
        
	}
		/**
	 * Get repay-blog-post categories.
	 *
	 * Retrieve the repay-blog-post categories to populate the category control.
	 *
	 * @since 1.0.0
	 * @access protected
	 * @return array repay-blog-post categories.
	 */
	protected function get_post_blog_categories() {
		$categories = get_categories( array( 'taxonomy' => 'category' ) );
		$options = array();

		foreach ( $categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}
		return $options;
	}
	/**
	 * Render repay-blog-post widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$number_of_post_blogs = $settings['number_of_post_blogs'];
		$category = $settings['post_blog_category'];
		$image_size = $settings['image_size']; // Get the selected image size
		// Get user-selected post order (ascending or descending)
		$post_order = ($settings['post_order'] === 'desc') ? 'DESC' : 'ASC';
		// Get user-selected sorting order (latest posts or alphabetical)
		$post_order_by = ($settings['post_order_by'] === 'date') ? 'date' : 'title';
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => $number_of_post_blogs,
			'order'          => $post_order,    // Use user-selected post order
			'orderby'        => $post_order_by, // Use user-selected sorting order
		);
		
		// Check if a specific category is selected
		if (!empty($category) && $category != 'post') {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'Name',
					'terms'    => $category,
				),
			);
		}
		
		$result = new WP_Query($args);
		echo '<div class="blog-section">';
		if ($result->have_posts()) {
			echo '<div class="row">';
			$count = 0;
			while ($result->have_posts()) {
				$result->the_post();
				$post_id = get_the_ID();
				$meta = get_the_post_thumbnail(get_the_ID(), 'large');
				$comment_count = get_comments_number($post_id);
				?>
				<div class="col-lg-4 col-md-6 col-sm-6 col-12">
					<div class="blog-box">
						<figure>
							<?php
							if(has_post_thumbnail()) {
								echo the_post_thumbnail();
							}
							else {
								?>
								<img src="<?php echo PLUGIN_BASE_URI . 'assets/images/blog-default-img.jpg'?>" class="img-fluid">
								<?php
							}
							?>
						</figure>
						<div class="content">
							<?php 
							// Loop through each category
							$categories = get_the_category();
							foreach ($categories as $category) {
								// if($category) {
									echo '<a class="button" href="' . esc_url(get_category_link($category->term_id)) . '">' . esc_html($category->name) . '</a>';
								// }
							}
							?>
							<h4><?php echo the_title(); ?></h4>
							<a class="read-more" href="<?php echo the_permalink(); ?>"><?= (!empty($settings['button_text']))?$settings['button_text']:'Read More' ?></a>
						</div>
					</div>
				</div>
				<?php
			}
		}
		echo '</div>';
		?>
		<?php
	}
	
	

}
