<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor repay-case-studies Widget.
 *
 * Elementor widget that uses the repay-case-studies control.
 *
 * @since 1.0.0
 */
class Elementor_Repay_Case_Studies_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve repay-case-studies widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'repay-case-studies';
	}
	/**
	 * Get widget title.
	 *
	 * Retrieve repay-case-studies widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Repay Case Studies', 'elementor-repay-case-studies-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve repay-case-studies widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-code';
	}

	/**
	 * Register repay-case-studies widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
        
        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-repay-case-studies-control' ),
				'type' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'selected_case_studies',
			[
				'label' => esc_html__('Select Services', 'elementor-services-post-control'),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_case_studies_options(), // Define a function to get available services options
			]
		);
		$this->add_control(
			'number_of_repay_case_studies',
			[
				'label' => __( 'Number of Case Studies', 'elementor-repay-case-studies-control' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 4, // Set a default value
				'min' => 1,
				'max' => 100,
				'step' => 1,
			]
		);
		$this->add_control(
			'button_text', [
				'label' => __( 'Button Text', 'elementor-repay-case-studies-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Read More' , 'elementor-repay-case-studies-control' ),
				'label_block' => true,
			]
		);
        $this->end_controls_section();
		$this->start_controls_section(
			'query_section',
			[
				'label' => esc_html__('Query Settings', 'elementor-repay-case-studies-control'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => esc_html__('Order By', 'elementor-repay-case-studies-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'ID' => esc_html__('Post ID', 'elementor-repay-case-studies-control'),
					'title' => esc_html__('Title', 'elementor-repay-case-studies-control'),
					'date' => esc_html__('Date', 'elementor-repay-case-studies-control'),
					// Add other options as needed
				],
				'default' => 'ID', // Default order by Post ID
			]
		);
		
		$this->add_control(
			'post_status',
			[
				'label' => esc_html__('Post Status', 'elementor-repay-case-studies-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'publish' => esc_html__('Publish', 'elementor-repay-case-studies-control'),
					'draft' => esc_html__('Draft', 'elementor-repay-case-studies-control'),
					// Add other options as needed
				],
				'default' => 'publish', // Default post status is 'publish'
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => esc_html__('Order', 'elementor-repay-case-studies-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__('Ascending', 'elementor-repay-case-studies-control'),
					'DESC' => esc_html__('Descending', 'elementor-repay-case-studies-control'),
				],
				'default' => 'DESC', // Default order is descending
			]
		);
	}

	private function get_case_studies_options() {
		$options = [];
		$args = array(
			'post_type' => 'repay_case_studies',
			'posts_per_page' => -1,
			'post_status' => 'publish',
		);
		$services = new WP_Query($args);
	
		if ($services->have_posts()) {
			while ($services->have_posts()) {
				$services->the_post();
				$options[get_the_ID()] = get_the_title();
			}
			wp_reset_postdata();
		}
	
		return $options;
	}

	/**
	 * Render repay-case-studies widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$number_of_repay_case_studies = $settings['number_of_repay_case_studies'];
		$selected_case_studies = $settings['selected_case_studies'];
        ?>
        <?php
    	$args = array(
			'post_type' => 'repay_case_studies',
			'orderby' => $this->get_settings('orderby'),
			'post_status' => $this->get_settings('post_status'),
			'order' => $this->get_settings('order'),
			'posts_per_page' => $number_of_repay_case_studies,
			'post__in' => $selected_case_studies, // Include only the selected services
		);	
		$result = new WP_Query( $args );
		echo '<div class="case-studies-section position-relative">';
		if ( $result-> have_posts() ) {
			
			?>
			<?php
			echo '<div class="row">';
				$count=0;
				while ( $result->have_posts() ){ 
					$result->the_post();
					$meta = get_post_meta(get_the_ID(),'repay_case_studies_thumbnail', true);
					?>
					<div class="col-lg-6 col-md-6 col-sm-6 col-12">
						<div class="case-studies-box position-relative">
							<figure class="mb-0">
								<img src="<?php echo $meta; ?>" alt="" class="img-fluid">
							</figure>
							<h3 class="case-studies-title"><?php echo get_the_title(); ?></h3>
							<p><?php echo wp_trim_words( get_the_content(), 22 ); ?></p>
							<a href="<?php echo get_permalink(); ?>" class="more"><?= (!empty($settings['button_text']))?$settings['button_text']:'Read More'?></a>
						</div>
					</div>
					<?php
					$count++;
				}   
			echo '</div>';
	    }
		echo '</div>';
		?>
        <?php
		
	}

}
