<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor repay-services Widget.
 *
 * Elementor widget that uses the repay-services control.
 *
 * @since 1.0.0
 */
class Elementor_Repay_Services_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve repay-services widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'repay-services';
	}
	/**
	 * Get widget title.
	 *
	 * Retrieve repay-services widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Repay Services', 'elementor-repay-services-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve repay-nav-menu widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-code';
	}

	/**
	 * Register repay-services widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
        // Content Tab Controls Start
        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-repay-services-control' ),
				'type' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'selected_services',
			[
				'label' => esc_html__('Select Services', 'elementor-services-post-control'),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_services_options(), // Define a function to get available services options
			]
		);
		$this->add_control(
			'selected_style',
			[
				'label' => esc_html__( 'Select Style', 'elementor-repay-services-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1', // Set the default style
				'options' => [
					'style1' => esc_html__( 'Style 1', 'elementor-repay-services-control' ),
					'style2' => esc_html__( 'Style 2', 'elementor-repay-services-control' ),
					'style3' => esc_html__( 'Style 3', 'elementor-repay-services-control' ),
				],
			]
		);	
		$this->add_control(
			'number_of_services_box',
			[
				'label' => __( 'Number of Services', 'elementor-repay-services-control' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 6, // Set a default value
				'min' => 1,
				'max' => 100,
				'step' => 1,
			]
		);
		$this->add_control(
			'button_text', [
				'label' => __( 'Button Text', 'elementor-repay-services-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'More' , 'elementor-repay-services-control' ),
				'label_block' => true,
			]
		);
        $this->end_controls_section();
		$this->start_controls_section(
			'query_section',
			[
				'label' => esc_html__('Query Settings', 'elementor-repay-services-control'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => esc_html__('Order By', 'elementor-repay-services-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'ID' => esc_html__('Post ID', 'elementor-repay-services-control'),
					'title' => esc_html__('Title', 'elementor-repay-services-control'),
					'date' => esc_html__('Date', 'elementor-repay-services-control'),
					// Add other options as needed
				],
				'default' => 'ID', // Default order by Post ID
			]
		);
		
		$this->add_control(
			'post_status',
			[
				'label' => esc_html__('Post Status', 'elementor-repay-services-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'publish' => esc_html__('Publish', 'elementor-repay-services-control'),
					'draft' => esc_html__('Draft', 'elementor-repay-services-control'),
					// Add other options as needed
				],
				'default' => 'publish', // Default post status is 'publish'
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => esc_html__('Order', 'elementor-repay-services-control'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__('Ascending', 'elementor-repay-services-control'),
					'DESC' => esc_html__('Descending', 'elementor-repay-services-control'),
				],
				'default' => 'DESC', // Default order is descending
			]
		);
        
	}

	private function get_services_options() {
		$options = [];
		$args = array(
			'post_type' => 'repay_services',
			'posts_per_page' => -1,
			'post_status' => 'publish',
		);
		$services = new WP_Query($args);
	
		if ($services->have_posts()) {
			while ($services->have_posts()) {
				$services->the_post();
				$options[get_the_ID()] = get_the_title();
			}
			wp_reset_postdata();
		}
	
		return $options;
	}
	/**
	 * Render repay-services widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$selected_style = $settings['selected_style'];
		$selected_services = $settings['selected_services'];
		$number_of_services_box = $settings['number_of_services_box'];
        ?>
        <?php
    	$args = array(
			'post_type' => 'repay_services',
			'orderby' => $this->get_settings('orderby'),
			'post_status' => $this->get_settings('post_status'),
			'order' => $this->get_settings('order'),
			'posts_per_page' => $number_of_services_box,
			'post__in' => $selected_services, // Include only the selected services
		);	
		$result = new WP_Query( $args );
		if($selected_style === 'style1') {
			echo '<div class="service-section">';
				echo '<div class="services-data">';
				if ( $result-> have_posts() ) {
					?>
					<?php
					echo '<div class="row">';
						$count=0;
						while ( $result->have_posts() ){ 
							$result->the_post();
							$meta = get_post_meta(get_the_ID(),'repay_services_thumbnail', true);
							?>
							<div class="col-lg-4 col-md-4 col-sm-6 col-12">
								<div class="service-box">
									<figure class="img">
										<img src="<?php echo $meta ?>" alt="" class="img-fluid">
									</figure>
									<div class="content">
										<h3><?php echo get_the_title(); ?></h3>
										<p><?php echo wp_trim_words( get_the_content(), 15 ) ; ?></p>
										<a href="<?php echo get_permalink(); ?>" class="more"><?= (!empty($settings['button_text']))?$settings['button_text']:'More' ?></a>
									</div>
								</div>
							</div>
							<?php
							$count++;
						}   
					echo '</div>';
				}
				echo '</div>';
			echo '</div>';
		}
		elseif($selected_style === 'style2') {
			echo '<div class="service-section streamlined-service-section">';
				echo '<div class="services-data">';
				if ( $result-> have_posts() ) {
					?>
					<?php
					echo '<div class="row">';
						$count=0;
						while ( $result->have_posts() ){ 
							$result->the_post();
							$meta = get_post_meta(get_the_ID(),'repay_services_thumbnail', true);
							?>
							<div class="col-lg-6 col-md-6 col-sm-6 col-12">
								<div class="service-box">
									<div class="img-outer">
										<figure class="img">
											<img src="<?php echo $meta ?>" alt="" class="img-fluid">
										</figure>
									</div>
									<div class="content">
										<h3><?php echo get_the_title(); ?></h3>
										<p><?php echo wp_trim_words( get_the_content(), 15 ) ; ?></p>
										<a href="<?php echo get_permalink(); ?>" class="more"><?= (!empty($settings['button_text']))?$settings['button_text']:'More' ?></a>
									</div>
								</div>
							</div>
							<?php
							$count++;
						}   
					echo '</div>';
				}
				echo '</div>';
			echo '</div>';
		}
		elseif($selected_style === 'style3') {
			echo '<div class="service-section streamlined-service-section seamless-service-section">';
				echo '<div class="services-data">';
				if ( $result-> have_posts() ) {
					?>
					<?php
					echo '<div class="row">';
						$count=0;
						while ( $result->have_posts() ){ 
							$result->the_post();
							$meta = get_post_meta(get_the_ID(),'repay_services_thumbnail', true);
							?>
							<div class="col-lg-6 col-md-6 col-sm-6 col-12">
								<div class="service-box">
									<figure class="img">
										<img src="<?php echo $meta ?>" alt="" class="img-fluid">
									</figure>
									<div class="content">
										<h4><?php echo get_the_title(); ?></h4>
										<p><?php echo wp_trim_words( get_the_content(), 11 ) ; ?></p>
										<a href="<?php echo get_permalink(); ?>" class="more"><?= (!empty($settings['button_text']))?$settings['button_text']:'More' ?></a>
									</div>
								</div>
							</div>
							<?php
							$count++;
						}   
					echo '</div>';
				}
				echo '</div>';
			echo '</div>';
		}
		
	}

}
