<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor repay-testimonial-slider Widget.
 *
 * Elementor widget that uses the repay-testimonial-slider control.
 *
 * @since 1.0.0
 */
class Elementor_Repay_Testimonial_Slider_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve repay-testimonial-slider widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'repay-testimonial-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve repay-testimonial-slider widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Repay Testimonial Slider', 'elementor-repay-testimonial-slider-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve repay-testimonial-slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-carousel-loop';
	}

	/**
	 * Register repay-testimonial-slider widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-repay-testimonial-slider-control' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'selected_style',
			[
				'label' => esc_html__( 'Select Style', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1', // Set the default style
				'options' => [
					'style1' => esc_html__( 'Style 1', 'elementor-repay-testimonial-slider-control' ),
					'style2' => esc_html__( 'Style 2', 'elementor-repay-testimonial-slider-control' ),
					'style3' => esc_html__( 'Style 3', 'elementor-repay-testimonial-slider-control' ),
				],
			]
		);	
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'list_content', [
				'label' => __( 'Content', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( 'List Content' , 'elementor-repay-testimonial-slider-control' ),
				'label_block' => true,
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'list_image',
			[
				'label' => esc_html__( 'Image', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'label_block' => true,
				'default' => [
					'url' => PLUGIN_BASE_URI. 'assets/images/testimonial-default-img.png' ,
				],
			]
		);
		$repeater->add_control(
			'list_name', [
				'label' => __( 'Name', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Name' , 'elementor-repay-testimonial-slider-control' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'list_designation', [
				'label' => __( 'Designation', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Designation' , 'elementor-repay-testimonial-slider-control' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'list',
			[
				'label' => __( 'Testimonial List', 'elementor-repay-testimonial-slider-control' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_content' => __( 'Content', 'elementor-repay-testimonial-slider-control' ),
						'list_image' => __( 'Image', 'elementor-repay-testimonial-slider-control' ),
						'list_name' => __( 'Name', 'elementor-repay-testimonial-slider-control' ),
						'list_designation' => __( 'Designation', 'elementor-repay-testimonial-slider-control' ),
					],
					[
						'list_content' => __( 'Content', 'elementor-repay-testimonial-slider-control' ),
						'list_image' => __( 'Image', 'elementor-repay-testimonial-slider-control' ),
						'list_name' => __( 'Name', 'elementor-repay-testimonial-slider-control' ),
						'list_designation' => __( 'Designation', 'elementor-repay-testimonial-slider-control' ),
					],
				],
			]
		);
	}


	/**
	 * Render repay-testimonial-slider widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$selected_style = $settings['selected_style'];
		if($selected_style === 'style1') {
			?>
			<div class="testimonial-section testimonial-wrapper">
				<div id="testimonialcarousel" class="carousel slide" data-bs-ride="carousel">
					<div class="carousel-inner">
						<?php
						$count = 0;
						if ( $settings['list'] ) {
							foreach ( $settings['list'] as $item ) {				
								?>
								<div class="carousel-item <?php if($count==0){echo 'active';} ?>">
									<div class="review_content">
										<?php 
										if(isset($item['list_image']['id']) && !empty( $item['list_image']['id'] )) {
											?>
											<?php echo wp_get_attachment_image( $item['list_image']['id'], 'full' ); ?>
											<?php
										}
										else {
											?>
											<img src="<?php echo PLUGIN_BASE_URI .'/assets/images/testimonial-default-img.png' ;?>" alt="" class="img-fluid">
											<?php
										}
										if($item['list_content']) {
											?>
											<p class="content"><?php echo strip_tags($item['list_content']) ?></p>
											<?php
										}
										if($item['list_name']) {
											?>
											<h4 class="mb-0"><?php echo $item['list_name'] ?></h4>
											<?php
										}
										if($item['list_designation']) {
											?>
											<span><?php echo $item['list_designation'] ?></span>
											<?php
										}
										?>
									</div>
								</div>
								<?php
								$count++;
							}
						}
						?>
					</div> 
					<div class="pagination-outer">
						<a class="carousel-control-prev" href="#testimonialcarousel" role="button" data-slide="prev">
							<i class="fa-solid fa-arrow-left"></i>
						</a>
						<a class="carousel-control-next" href="#testimonialcarousel" role="button" data-slide="next">
							<i class="fa-solid fa-arrow-right"></i>
						</a>
					</div>
				</div>
				<figure class="mb-0 testimonial-circle">
					<img src="<?php echo PLUGIN_BASE_URI .'/assets/images/testimonial-bg.png' ;?>" alt="">
				</figure>
			</div>	
			<?php
		}
		elseif($selected_style === 'style2') {
			?>
			<div class="streamlined-testimonial-section">
				<div class="owl-carousel owl-theme">
					<?php
					if ( $settings['list'] ) {
						foreach ( $settings['list'] as $item ) {				
							?>
							<div class="testimonial-box">
								<div class="testimonial-box-inner">
									<figure class="quote">
										<img class="img-fluid" src="<?php echo PLUGIN_BASE_URI .'/assets/images/quote-icon.png' ;?>" alt="">
									</figure>
									<?php
									if($item['list_content']) {
										?>
										<p class="content"><?php echo strip_tags($item['list_content']) ?></p>
										<?php
									}
									if($item['list_name']) {
										?>
										<h3><?php echo $item['list_name'] ?></h3>
										<?php
									}
									if($item['list_designation']) {
										?>
										<span><?php echo $item['list_designation'] ?></span>
										<?php
									}
									?>
								</div>
								<div class="user-img">
									<?php
									if(isset($item['list_image']['id']) && !empty( $item['list_image']['id'] )) {
										?>
										<?php echo wp_get_attachment_image( $item['list_image']['id'], 'full' ); ?>
										<?php
									}
									else {
										?>
										<img src="<?php echo PLUGIN_BASE_URI .'/assets/images/testimonial-default-img.png' ;?>" alt="" class="img-fluid">
										<?php
									}
									?>
								</div>	
							</div>
							<?php
						}	
					?>
				</div>	
			</div>
			<?php		
			}
		}
		elseif($selected_style === 'style3') {
			?>
			<div class="seamless-testimonial-section">
				<div class="owl-carousel owl-theme">
					<?php
					if ( $settings['list'] ) {
						foreach ( $settings['list'] as $item ) {				
							?>
							<div class="testimonial-box">
								<figure class="quote">
									<img class="img-fluid" src="<?php echo PLUGIN_BASE_URI .'/assets/images/testimonial-quote-icon.png' ;?>" alt="">
								</figure>
								<div class="user-outer">
									<div class="user-img">
										<?php
										if(isset($item['list_image']['id']) && !empty( $item['list_image']['id'] )) {
											?>
											<?php echo wp_get_attachment_image( $item['list_image']['id'], 'full' ); ?>
											<?php
										}
										else {
											?>
											<img src="<?php echo PLUGIN_BASE_URI .'/assets/images/testimonial-default-img.png' ;?>" alt="" class="img-fluid">
											<?php
										}
										?>
									</div>
									<div class="name-outer">
										<?php
										if($item['list_name']) {
											?>
											<h3><?php echo $item['list_name'] ?></h3>
											<?php
										}
										if($item['list_designation']) {
											?>
											<span><?php echo $item['list_designation'] ?></span>
											<?php
										}
										?>
									</div>
								</div>	
								<?php
								if($item['list_content']) {
									?>
									<p class="content mb-0"><?php echo strip_tags($item['list_content']) ?></p>
									<?php
								}
								?>
							</div>
							<?php
						}	
					?>
				</div>	
			</div>
			<?php		
			}
		}
	}

}